@@ -3,7 +3,7 @@ package Meow;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 # Store specs for use after JIT compilation (for inheritance)
 # This is accessed from XS via get_hv("Meow::SPECS", ...)
@@ -24,7 +24,7 @@ Meow - Object ฅ^•ﻌ•^ฅ Orientation
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
@@ -249,27 +249,36 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 
 ...
 
-	Benchmark: timing 5000000 iterations of Cor, Marlin, Meow, Moo, Mouse...
-	       Cor:  0 wallclock secs ( 1.72 usr +  0.00 sys =  1.72 CPU) @ 2906976.74/s (n=5000000)
-	    Marlin:  0 wallclock secs ( 1.06 usr +  0.02 sys =  1.08 CPU) @ 4629629.63/s (n=5000000)
-	      Meow:  1 wallclock secs ( 1.08 usr +  0.00 sys =  1.08 CPU) @ 4629629.63/s (n=5000000)
-	       Moo:  6 wallclock secs ( 5.79 usr +  0.03 sys =  5.82 CPU) @ 859106.53/s (n=5000000)
-	     Mouse:  4 wallclock secs ( 3.12 usr +  0.01 sys =  3.13 CPU) @ 1597444.09/s (n=5000000)
-		    Rate    Moo  Mouse    Cor Marlin   Meow
-	Moo     859107/s     --   -46%   -70%   -81%   -81%
-	Mouse  1597444/s    86%     --   -45%   -65%   -65%
-	Cor    2906977/s   238%    82%     --   -37%   -37%
-	Marlin 4629630/s   439%   190%    59%     --    -0%
-	Meow   4629630/s   439%   190%    59%     0%     --
+	Benchmark: timing 5,000,000 iterations of Marlin, Meow, Moo, Mouse...
+	    Marlin:  1 wallclock secs ( 0.98 usr +  0.02 sys =  1.00 CPU) @ 5000000.00/s (n=5000000)
+	      Meow:  1 wallclock secs ( 0.96 usr +  0.00 sys =  0.96 CPU) @ 5208333.33/s (n=5000000)
+	       Moo:  6 wallclock secs ( 5.70 usr +  0.00 sys =  5.70 CPU) @ 877192.98/s (n=5000000)
+	     Mouse:  3 wallclock secs ( 3.05 usr +  0.01 sys =  3.06 CPU) @ 1633986.93/s (n=5000000)
+
+		    Rate    Moo  Mouse Marlin   Meow
+	Moo     877193/s     --   -46%   -82%   -83%
+	Mouse  1633987/s    86%     --   -67%   -69%
+	Marlin 5000000/s   470%   206%     --    -4%
+	Meow   5208333/s   494%   219%     4%     --
 
 Note: Type::Tiny::XS is installed and so is the other optional XS dependancies for Moo.
 
-The limitation is now my hardware with Marlin and Meow.
-
-	Benchmark: running Cor, Marlin, Meow for at least 5 CPU seconds...
+	Benchmark: running Cor, Marlin for at least 5 CPU seconds... Marlin and Meow has type constraint checking
 	       Cor:  5 wallclock secs ( 5.13 usr +  0.02 sys =  5.15 CPU) @ 2886788.16/s (n=14866959)
 	    Marlin:  5 wallclock secs ( 5.01 usr +  0.11 sys =  5.12 CPU) @ 4523074.80/s (n=23158143)
-	      Meow:  5 wallclock secs ( 5.16 usr +  0.02 sys =  5.18 CPU) @ 4558344.59/s (n=23612225)
+	      Meow:  5 wallclock secs ( 5.16 usr + -0.01 sys =  5.15 CPU) @ 5196218.06/s (n=26760523)
+	
+	Benchmark: running Marlin, Meow, Moo, Mouse for at least 5 CPU seconds...
+	    Marlin:  5 wallclock secs ( 5.22 usr +  0.13 sys =  5.35 CPU) @ 4814728.04/s (n=25758795)
+	      Meow:  5 wallclock secs ( 5.23 usr +  0.01 sys =  5.24 CPU) @ 5203329.96/s (n=27265449)
+	       Moo:  4 wallclock secs ( 5.28 usr +  0.00 sys =  5.28 CPU) @ 860649.81/s (n=4544231)
+	     Mouse:  6 wallclock secs ( 5.29 usr +  0.01 sys =  5.30 CPU) @ 1603849.25/s (n=8500401)
+
+		    Rate    Moo  Mouse Marlin   Meow
+	Moo     860650/s     --   -46%   -82%   -83%
+	Mouse  1603849/s    86%     --   -67%   -69%
+	Marlin 4814728/s   459%   200%     --    -7%
+	Meow   5203330/s   505%   224%     8%     --
 
 =head1 AUTHOR
 
